/*########################################################################

  Demo program that shows how to use the FVS library to improve
  fingerprint images. At the moment the library supports the import
  of bitmap images. The result is exported as a bitmap image as well.

  Link this sample with the FVS library (libfvs)

########################################################################*/


#include "fvs.h"


static void ExportImage(const FvsImage_t image, const FvsString_t filename)
{
    FvsFile_t file = FileCreate();
    if (file!=NULL)
    {
        fprintf(stdout, "exporting resulting image to %s\n", filename);
        (void)FileOpen    (file, filename, FvsFileCreate|FvsFileWrite);
        (void)BitmapExport(file, image);
        (void)FileClose   (file);
        FileDestroy(file);
    }
}

static void ImportImage(FvsImage_t image, const FvsString_t filename)
{
    FvsFile_t file = FileCreate();
    if (file!=NULL)
    {
        fprintf(stdout, "Opening file %s...\n", filename);
        (void)FileOpen  (file, filename, FvsFileRead);
        (void)AutoImport(file, image);
        (void)FileClose (file);
        FileDestroy(file);
    }
}


int main(int argc, char *argv[])
{
    FvsImage_t mask;
    FvsImage_t image;
    FvsFloatField_t direction;
    FvsFloatField_t frequency;

    /* check if all parameters are there */
    if (argc!=3)
    {
        printf("Usage: fvs input.bmp output.bmp\n");
        return -1;
    }

    mask      = ImageCreate();
    image     = ImageCreate();
    direction = FloatFieldCreate();
    frequency = FloatFieldCreate();

    if (mask!=NULL && image!=NULL && direction!=NULL && frequency!=NULL)
    {
        ImportImage(image, argv[1]);

        /* normalize the image */
        (void)ImageNormalize(image, (FvsByte_t)128, (FvsUint_t)128*128);

        fprintf(stdout, "1/4 Determining the ridge direction\n");
        (void)FingerprintGetDirection(image, direction, 7, 2);

        fprintf(stdout, "2/4 Determining the ridge frequency\n");
        (void)FingerprintGetFrequency(image, direction, frequency);

        fprintf(stdout, "3/4 Creating the mask\n");
        (void)FingerprintGetMask(image, direction, frequency, mask);

        fprintf(stdout, "4/4 Enhancing the fingerprint image\n");
        (void)ImageEnhanceGabor(image, direction, frequency, mask);

        ExportImage(image, argv[2]);
    }
    fprintf(stdout, "Cleaning up and exiting...\n");
    FloatFieldDestroy(frequency);
    FloatFieldDestroy(direction);
    ImageDestroy(image);
    ImageDestroy(mask);
    return 0;
}


